// A library for the cheap but useful 28BYJ-48 5v stepper motor with ULN2003 driver board
// Changelog
// 20190720: NEW
#pragma once
#include "B4RDefines.h"
#include "CheapStepper.h"

namespace B4R {
	//~Version: 1.0
	//~shortname: CheapStepper
	class B4RCheapStepper {
		private:
			CheapStepper* bn;
			uint8_t be[sizeof(CheapStepper)];
		public:

			
			/**
			*
			*Initializes the CheapStepper object with the pin numbers to be used
			*
			*/			
			void Initialize(int in1, int in2, int in3, int in4);	
			
			/**
			*
			*sets speed (10-24 rpm, hi-low torque)
			*smaller than 6 rpm blocked in code, may overheat
			*23-24rpm may skip
			*
			*/		
			void setRpm (int rpm);
			/**
			*
			*set number of steps to 4096 per revolution
			*
			*/				
			void set4096StepMode();
			
			/**
			*
			*allows custom number of steps (usually 4076)
			*
			*/	
			void setTotalSteps (int numSteps);
			
			/**
			*
			*4096 steps = 1 revolution
			*blocking! (pauses the arduino until the move is done)
			*
			*/					
			void move (bool clockwise, int numSteps); 

			/**
			*
			*4096 steps = 1 revolution
			*
			*/					
			void moveTo (bool clockwise, int toStep);	
			/**
			*
			*move number of degrees in specified direction
			*
			*/	
			void moveDegrees (bool clockwise, int deg);	
			/**
			*
			*move to specified degrees and in specified direction
			*
			*/	
			void moveToDegree (bool clockwise, int deg);
				
			/**
			*
			*move 1 step clockwise or counter-clockwise
			*
			*/				
			void stepSingle (bool clockwise);

			/**
			*
			*returns the remaining steps in the current move
			*
			*/				
			int getRemaingSteps();
			
			
			
			void newMove (bool clockwise, int numSteps);
			void newMoveTo (bool clockwise, int toStep);
			/**
			*
			*move specified number of degrees from current position in specified direction
			*
			*/		
			void newMoveDegrees (bool clockwise, int deg);
			void newMoveToDegree (bool clockwise, int deg);

			int getCurrentRpm();
			
			void run();
			
	};

}